<?php
/**
 * Plugin Name: Nicole SEO Indicator
 * Description: A plugin to evaluate SEO results for blog posts. For copywriting beginners.
 * Version: 1.0
 * Author: Anna Nicole Plugins
 *License: GPLv2 or later
 *License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Add admin menu
function nicole_seo_add_admin_menu() {
    add_menu_page(
        __('Nicole SEO', 'nicole-seo-indicator'),
        __('NicoleSeo', 'nicole-seo-indicator'),
        'manage_options',
        'nicole-seo-indicator',
        'nicole_seo_admin_page',
        'dashicons-chart-line',
        6
    );
}
add_action('admin_menu', 'nicole_seo_add_admin_menu');

// Admin page content
function nicole_seo_admin_page() {
    ?>
    <div class="wrap">
        <h1><?php _e('Nicole SEO Settings', 'nicole-seo-indicator'); ?></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('nicole_seo_options_group');
            do_settings_sections('nicole-seo-indicator');
            submit_button();
            ?>
        </form>
    </div>
    <h2><?php _e('Jak zlepšit SEO optimalizaci, si můžete přečíst níže.', 'nicole-seo-indicator'); ?></h2>
    <p><?php _e('Optimalizace pro vyhledávače (SEO) je důležitým aspektem, který vám pomůže zvýšit návštěvnost vašich stránek. Tady je několik tipů, jak zlepšit SEO optimalizaci u vašich článků:
1. Klíčová slova

    Výzkum klíčových slov: Najděte relevantní klíčová slova, která hledají vaši čtenáři.

    Optimalizace nadpisů a obsahu: Zahrňte klíčová slova do nadpisu, prvního odstavce a dalších částí článku.

2. Struktura obsahu

    Používejte nadpisy (H2, H3,...): Pomáhají vyhledávačům lépe porozumět struktuře článku a usnadňují čtení.

    Rozdělte text do odstavců: Dlouhé texty rozdělte do kratších odstavců, které jsou snáze čitelné.

3. Interní a externí odkazy

    Interní odkazy: Odkazujte na další relevantní články na vašem webu.

    Externí odkazy: Odkazujte na důvěryhodné externí zdroje, které podporují vaši argumentaci.

4. Optimalizace obrázků

    Alternativní text (alt text): Každý obrázek by měl mít popisný alt text obsahující klíčová slova.

    Velikost obrázků: Optimalizujte velikost obrázků, aby se stránky rychleji načítaly.

5. Meta popisy

    Vytvářejte zajímavé meta popisy: Meta popisy by měly být atraktivní a obsahovat klíčová slova. Přitahují uživatele k prokliku.

6. Délka a kvalita obsahu

    Dlouhé články: Dlouhé články (500+ slov) často dosahují lepších výsledků ve vyhledávání.

    Kvalitní obsah: Zaměřte se na poskytování hodnotného a kvalitního obsahu, který čtenáři ocení.

7. Rychlost načítání stránky

    Optimalizace rychlosti: Rychle načítané stránky mají lepší uživatelskou zkušenost a vyšší hodnocení ve vyhledávačích.

8. Mobilní optimalizace

    Responsivní design: Ujistěte se, že vaše stránky jsou optimalizovány pro mobilní zařízení.

9. Sociální média

    Sdílení na sociálních médiích: Podpořte sdílení článků na sociálních médiích, což může zvýšit návštěvnost a zpětné odkazy.', 'nicole-seo-indicator'); ?></p>
    <?php
}

// Register settings
function nicole_seo_register_settings() {
    register_setting('nicole_seo_options_group', 'nicole_seo_main_title');
    register_setting('nicole_seo_options_group', 'nicole_seo_meta_description');

    add_settings_section('nicole_seo_main_section', __('Main Settings', 'nicole-seo-indicator'), null, 'nicole-seo-indicator');
    
    add_settings_field('nicole_seo_main_title', __('Main Title', 'nicole-seo-indicator'), 'nicole_seo_main_title_callback', 'nicole-seo-indicator', 'nicole_seo_main_section');
    add_settings_field('nicole_seo_meta_description', __('Meta Description', 'nicole-seo-indicator'), 'nicole_seo_meta_description_callback', 'nicole-seo-indicator', 'nicole_seo_main_section');
}
add_action('admin_init', 'nicole_seo_register_settings');

function nicole_seo_main_title_callback() {
    $main_title = get_option('nicole_seo_main_title');
    echo '<input type="text" name="nicole_seo_main_title" value="' . esc_attr($main_title) . '" />';
}

function nicole_seo_meta_description_callback() {
    $meta_description = get_option('nicole_seo_meta_description');
    echo '<textarea name="nicole_seo_meta_description" rows="5" cols="50">' . esc_textarea($meta_description) . '</textarea>';
}

// Add meta box for SEO score
function nicole_seo_add_meta_box() {
    add_meta_box(
        'nicole_seo_meta_box',
        __('BLOG SEO SCORE', 'nicole-seo-indicator'),
        'nicole_seo_meta_box_callback',
        'post',
        'side'
    );
}
add_action('add_meta_boxes', 'nicole_seo_add_meta_box');

// Meta box callback
function nicole_seo_meta_box_callback($post) {
    $seo_score = nicole_seo_calculate_score($post->ID);
    ?>
    <div class="nicole-seo-score-box">
        <div class="nicole-seo-score-circle" style="background-color: <?php echo nicole_seo_get_score_color($seo_score); ?>;">
            <strong style="font-size: 24px;"><?php echo $seo_score; ?></strong>
        </div>
        <p><?php _e('Nicole Plugins', 'nicole-seo-indicator'); ?></p>
    </div>
    <?php
}

// Calculate SEO score
function nicole_seo_calculate_score($post_id) {
    $post = get_post($post_id);
    $content = $post->post_content;
    $seo_score = 0;

    // Criteria for SEO score
    if (strlen($post->post_title) >= 50 && strlen($post->post_title) <= 90) $seo_score += 5;
    if (strpos($content, '<h2>') !== false) $seo_score += 15;
    if (strpos($content, '<h3>') !== false) $seo_score += 15;
    if (substr_count($content, '</p>') > 1) $seo_score += 15;
    if (strpos($content, '<img') !== false) $seo_score += 15;
    if (preg_match('/<strong>.*?<\/strong>/', $content)) $seo_score += 5;
    if (preg_match('/<a href="http/', $content)) $seo_score += 5;
    if (preg_match('/<a href="\/[^"]/', $content)) $seo_score += 5;
    if (str_word_count($content) >= 100 && str_word_count($content) <= 500) $seo_score += 10;
    if (str_word_count($content) >= 501 && str_word_count($content) <= 800) $seo_score += 10;

    return $seo_score;
}

// Get score color
function nicole_seo_get_score_color($score) {
    if ($score <= 49) return 'red';
    if ($score >= 50 && $score <= 80) return 'lightgreen';
    if ($score >= 81) return 'green';
}

// Add CSS and JS
function nicole_seo_enqueue_scripts() {
    wp_enqueue_style('nicole-seo-styles', plugin_dir_url(__FILE__) . 'css/nicole-seo-indicator.css');
    wp_enqueue_script('nicole-seo-scripts', plugin_dir_url(__FILE__) . 'js/nicole-seo-indicator.js', array('jquery'), '1.0', true);
}
add_action('admin_enqueue_scripts', 'nicole_seo_enqueue_scripts');

// Add SEO score column to post list
function nicole_seo_add_columns($columns) {
    $columns['seo_score'] = __('SEO Score', 'nicole-seo-indicator');
    return $columns;
}
add_filter('manage_posts_columns', 'nicole_seo_add_columns');

function nicole_seo_custom_column($column, $post_id) {
    if ($column == 'seo_score') {
        $seo_score = nicole_seo_calculate_score($post_id);
        echo '<div class="nicole-seo-score" style="background-color: ' . nicole_seo_get_score_color($seo_score) . ';">';
        echo '<strong>' . $seo_score . '</strong>';
        echo '</div>';
    }
}
add_action('manage_posts_custom_column', 'nicole_seo_custom_column', 10, 2);
